package main

import "github.com/raitonoberu/sptlrx/cmd"

func main() {
	cmd.Execute()
}
